@@ -19,6 +19,7 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
+#include <syslog.h>
 
 #include <loc/libloc.h>
 #include <loc/database.h>
@@ -33,6 +34,9 @@ int main(int argc, char** argv) {
 	if (err < 0)
 		exit(EXIT_FAILURE);
 
+	// Enable debug logging
+	loc_set_log_priority(ctx, LOG_DEBUG);
+
 	struct loc_network_tree* tree;
 	err = loc_network_tree_new(ctx, &tree);
 	if (err) {
@@ -120,7 +124,7 @@ int main(int argc, char** argv) {
 	// Set ASN
 	loc_network_set_asn(network4, 1024);
 
-	FILE* f = fopen("test.db", "w+");
+	FILE* f = tmpfile();
 	if (!f) {
 		fprintf(stderr, "Could not open file for writing: %s\n", strerror(errno));
 		exit(EXIT_FAILURE);
@@ -131,8 +135,6 @@ int main(int argc, char** argv) {
 		fprintf(stderr, "Could not write database: %s\n", strerror(-err));
 		exit(EXIT_FAILURE);
 	}
-	fclose(f);
-
 	loc_writer_unref(writer);
 
 	loc_network_unref(network1);
@@ -142,12 +144,6 @@ int main(int argc, char** argv) {
 	loc_network_tree_unref(tree);
 
 	// And open it again from disk
-	f = fopen("test.db", "r");
-	if (!f) {
-		fprintf(stderr, "Could not open file for reading: %s\n", strerror(errno));
-		exit(EXIT_FAILURE);
-	}
-
 	struct loc_database* db;
 	err = loc_database_new(ctx, &db, f);
 	if (err) {
@@ -172,6 +168,7 @@ int main(int argc, char** argv) {
 	loc_network_unref(network1);
 
 	loc_unref(ctx);
+	fclose(f);
 
 	return EXIT_SUCCESS;
 }
